==> SexyMap-v8.3.0.zip: SexyMap/localization/ptBR.lua <==

if GetLocale() ~= "ptBR" then return end
local _, sm = ...
local L = sm.L
L["1. Background"] = "Fundo"
L["2. Border"] = "Borda"
L["3. Artwork"] = "Arte Visual" -- Needs review
L["4. Overlay"] = "Sobreposição" -- Needs review
L["5. Highlight"] = "Destaque" -- Needs review
L["Add Blend (additive)"] = "Adicionar Mistura (aditivo)" -- Needs review
L["Addon Buttons"] = "Botões de Addon"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Um perfil global já existe. Você será trocado para esse e sua interface (UI) será recarregada, você tem certeza disso?" -- Needs review
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Permitir que SexyMap assuma o direito de mover os botões no minimapa. Desligue isso se você tem outro mod que você pretende usar para posicionar seus botões do minimapa."
-- L["Alpha Key (1-bit alpha)"] = "Alpha Key (1-bit alpha)"
L["Always"] = "Sempre"
-- L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Are you sure you want to switch back to using a character specific profile? This will reload your UI."
L["Armored Man"] = "Homem Blindado" -- Needs review
L["A static amount to rotate the texture by."] = "Uma quantidade fixa para girar a textura por." -- Needs review
L["Auto Zoom-Out Delay"] = "Atraso do recuo do Zoom"
L["Backdrop Color"] = "Cor de fundo"
L["Backdrop Insets"] = "Inserções do Fundo" -- Needs review
L["Background Color"] = "Cor de fundo"
L["Background/edge"] = "Fundo/beira" -- Needs review
L["Background Texture"] = "Textura do Fundo"
L["Blend Mode"] = "Modo Misturar" -- Needs review
L["Blend (normal)"] = "Misturar (normal)" -- Needs review
L["Border Color"] = "Cor da Borda"
L["Border Edge Size"] = "Tamanho da beira da Borda"
L["Borders"] = "Bordas"
L["Border Texture"] = "Textura da Borda"
L["Boss Frames"] = "Quadros de Chefe"
L["Buttons"] = "Botões"
L["Calendar"] = "Calendário"
-- L["Capture Bars"] = "Capture Bars"
L["Challenge Mode Button (When Available)"] = "Botões do Modo Desafio (Quando disponível)"
L["Circle"] = "Círculo"
L["Clamp to screen"] = "Prender a tela" -- Needs review
L["Clear & start over"] = "Limpar e começar de novo"
L["Clear the current borders and start fresh"] = "Limpar as bordas existentes e começar de novo"
L["Clock"] = "Relógio"
L["Coordinates"] = "Coordenadas"
L["Copy a Profile"] = "Copiar um perfil"
L["Copying this profile will reload your UI, are you sure?"] = "Copiar esse perfil vai recarregar a interface (UI), você tem certeza disso?"
L["Create a new border"] = "Criar uma nova borda"
L["Current Borders"] = "Bordas atuais" -- Needs review
L["Default Presets"] = "Predefinições padrão" -- Needs review
L["Delete"] = "Deletar"
L["Delete a Profile"] = "Deletar um perfil"
L["Diamond"] = "Diamante"
L["Disable (opaque)"] = "Desabilitar (opacidade)"
L["Disable Rotation"] = "Desabilitar Rotação"
L["Disabling the movers will make them reset next time you relog, are you sure?"] = "Desabilitar os movedores irá fazer com que eles resetem na próxima vez que você relogar, você tem certeza disso?" -- Needs review
L["Drag Radius"] = "Área de arrasto" -- Needs review
L["Dungeon Difficulty Indicator (When Available)"] = "Indicador de Dificuldade de Masmorra (Quando disponível)"
L["Dynamic Buttons"] = "Botões dinâmicos"
L["Enable"] = "Habilitar"
-- L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Enable a backdrop and border for the minimap. This will let you set square borders more easily."
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Habilitar o HUD do minimapa. Isto é muito útil para coletar recursos, mas por motivos técnicos, o HUD do mapa e o minimapa normal não podem ser exibidos ao mesmo tempo. Ligando o HUD do mapa irá desligar o minimapa." -- Needs review
L["Enable Coordinates"] = "Habilitar Coordenadas"
L["Enable Hudmap"] = "Habilitar Hudmap"
L["Enable Minimap Fader"] = "Habilitar Ocultação do Minimapa" -- Needs review
L["Enable Movers"] = "Habilitar Movedores" -- Needs review
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Coloque um nome para criar uma nova borda. O nome pode ser qualquer coisa que você ache que vai lhe ajudar a identificar a borda."
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Entre o caminho inteiro da textura que deseja usar. É recomendado que você use alguma Addon como |cffff6600TexBrowser|r para achar a textura que deseja usar."
-- L["Entry Options"] = "Entry Options"
-- L["Faded Circle (Large)"] = "Faded Circle (Large)"
-- L["Faded Circle (Small)"] = "Faded Circle (Small)"
-- L["Faded Square"] = "Faded Square"
-- L["Fader"] = "Fader"
L["Font"] = "Fonte"
L["Font Color"] = "Cor da Fonte"
L["Font Size"] = "Tamanho da fonte"
L["Force a square texture. Fixed distortion on square textures."] = "Forçar uma textura quadrada. Distorção fixa em texturas quadradas." -- Needs review
L["Garrison Button (When Available)"] = "Botão da Guarnição (Quando Disponível)" -- Needs review
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Indicador de dificuldade de Masmorra de Guilda (Quando disponível)"
L["Heart"] = "Coração" -- Needs review
L["Height"] = "Altura" -- Needs review
L["Hexagon"] = "Hexágono" -- Needs review
L["Hide default border"] = "Esconder borda padrão"
L["Hide the default border on the minimap."] = "Esconder a borda padrão no minimapa."
L["Horizontal Nudge"] = "Cutucada Horizontal" -- Needs review
L["Horizontal Position"] = "Posição Horizontal"
L["Hover Opacity"] = "Opacidade do mouse sobre o minimapa"
L["HUD Color"] = "Cor da HUD" -- Needs review
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "Se você aproximar o mapa, está função automaticamente afastará depois de um período de tempo (segundos). Usar o valor 0 desabilitará o afastamento automático." -- Needs review
L["Keybinding"] = "Tecla de atalho"
L["Layer"] = "Camada"
L["Let SexyMap control button visibility"] = "Deixar o SexyMap controlar a visibilidade dos botões"
L["Let SexyMap handle button dragging"] = "Deixar o SexyMap controlar o movimento dos botões"
L["Lock Button Dragging"] = "Bloquear o movimento de botões"
L["Lock Minimap"] = "Bloquear o minimapa"
L["Lock Movers"] = "Bloquear os Movedores" -- Needs review
L["Map Button"] = "Botão do mapa"
L["Minimap shape"] = "Formato do minimapa"
L["Mod Blend (modulative)"] = "Mistura do Mod (modular)" -- Needs review
L["Movers"] = "Movedores" -- Needs review
L["Movers Warning"] = "AVISO: Esta função não é oficialmente suportada, portanto espere por problemas ao usar esta função como impurezas, perda da funcionalidade do rastreador de missões, ou das janelas de chefe saltando pela tela. Os janelas da Blizzard como o rastreador de missão e saúde do chefe não foram criadas para serem movidas, eu sugiro que você use addons que substituam essas janelas, como por exemplo, Unit Frames para os chefes." -- Needs review
L["Name"] = "Nome"
L["Never"] = "Nunca"
L["New Mail Indicator (When Available)"] = "Indicador de nova carta (Quando disponível)"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "Não existe nenhum perfil global. Seu perfil em uso será copiado e usado como um perfil global, você tem certeza disso? Isto também irá recarregar sua interface (UI)." -- Needs review
L["Normal Opacity"] = "Opacidade normal"
L["Objectives Tracker"] = "Rastreador de Objetivos"
L["Octagon"] = "Octágono"
L["On Hover"] = "Mouse sobre o minimapa" -- Needs review
L["Opacity"] = "Opacidade"
L["Open TexBrowser"] = "Abrir TexBrowser"
L["Ping"] = "Silvo" -- Needs review
L["Preset"] = "Predefinido"
L["Prevent the minimap from being moved off the screen"] = "Previne que o minimapa seja movido fora dos limites de tela"
L["Profiles"] = "Perfis"
-- L["Queue Status (PvP/LFG) Button (When Available)"] = "Queue Status (PvP/LFG) Button (When Available)"
L["Quickly change the look of your minimap by using a minimap preset."] = "Mude rapidamente o visual de seu minimapa ao usar uma predefinição de minimapa."
L["Really delete this border?"] = "Deseja mesmo deletar essa borda?"
L["Really delete this preset? This can't be undone."] = "Deseja mesmo deletar essa predefinição? Este processo não poderá ser desfeito." -- Needs review
L["Really delete this profile?"] = "Deseja mesmo deletar este perfil?"
L["(Requires button visibility control in the Buttons menu)"] = "(Requer controle de visibilidade dos botôes no menu Botões)"
L["Reset Current Profile"] = "Resetar perfil atual" -- Needs review
L["Resetting this profile will reload your UI, are you sure?"] = "Resetar esse perfil irá recarregar sua interface (UI), você tem certeza disso?"
L["Right Click Configure"] = "Configuração ao clicar com o botão direito" -- Needs review
L["Right clicking the map will open the SexyMap options"] = "Clicar com o botão direito no mapa irá abrir as opções do SexyMap" -- Needs review
L["Rotation Speed (seconds)"] = "Velocidade da Rotação (segundos)" -- Needs review
L["Rounded - Bottom"] = "Arredondado - Canto Inferior" -- Needs review
L["Rounded - Bottom Left"] = "Arredondado - Canto Inferior Esquerdo" -- Needs review
L["Rounded - Bottom Right"] = "Arredondado - Canto Inferior Direito" -- Needs review
L["Rounded - Left"] = "Arredondado - Esquerdo" -- Needs review
L["Rounded - Right"] = "Arredondado - Direito" -- Needs review
L["Rounded - Top"] = "Arredondado - Canto Superior" -- Needs review
L["Rounded - Top Left"] = "Arredondado - Canto Superior Esquerdo" -- Needs review
L["Rounded - Top Right"] = "Arredondado - Canto Superior Direito" -- Needs review
L["Route 66"] = "Rota 66" -- Needs review
L["Save current settings as preset..."] = "Salvar definições em uso como predefinido..." -- Needs review
L["Scale"] = "Escala"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Selecione uma predefinição para carregar suas definições. Este processo irá apagar qualquer uma das suas bordas em uso." -- Needs review
L["Select preset to load"] = "Selecione predefinição para carregar" -- Needs review
L["SharedMedia Border"] = "Borda SharedMedia" -- Needs review
L["SharedMedia Texture"] = "Textura SharedMedia" -- Needs review
L["Show inside chat"] = "Mostrar dentro da janela de bate-papo" -- Needs review
L["Show North Tag"] = "Mostrar o indicador do Norte no minimapa"
L["Show on minimap"] = "Mostrar no minimapa"
L["Show %s:"] = "Mostrar %s:" -- Needs review
L["Show who pinged"] = "Mostrar quem deu o silvo" -- Needs review
L["Snowflake"] = "Floco de neve" -- Needs review
L["Spice up your minimap with some sexy options."] = "Dê uma apimentada no seu minimapa com algumas opções sexy."
L["Square"] = "Quadrado" -- Needs review
L["Standard Buttons"] = "Botões Padrões"
L["Static Rotation"] = "Rotação estática"
L["TexBrowser Not Installed"] = "TexBrowser não instalado"
L["Text Color"] = "Cor do texto"
L["Texture"] = "Textura"
L["Texture Options"] = "Opções de textura"
L["Texture Path"] = "Localização da textura"
L["Texture Tint"] = "Tintura da textura" -- Needs review
L["Text Width"] = "Largura do texto"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "O HudMap suporta vários addons. Se você tiver qualquer um dos addons abaixo instalado, eles será mostrado no HudMap." -- Needs review
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "O tempo que isso leva (em segundos) para completar uma rotação. Uma definição em 0 desliga a rotação." -- Needs review
L["This will wipe out any current settings!"] = "Isto irá apagar todas as outras configurações!"
L["Tile Background"] = "Fundo do azulejo" -- Needs review
L["Tile Size"] = "Tamanho do azulejo" -- Needs review
L["Toggle HudMap On/Off"] = "Ligar/Desligar HudMap"
L["Tracking Button"] = "Botão de Rastreamento"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Desligue isso se você quer que outro mod seja utilizado para controlar quais botões são visiveis no minimapa."
L["Use Global Profile"] = "Usar Perfil Global"
L["User-Submitted Presets"] = "Predefinições feitas por usuários"
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Use o perfil global se você quer o mesmo visual para todos os personagens, ou use um perfil específico-para-um-personagem para um visual único para cada personagem."
L["Vehicle Seat"] = "Assento do Veículo"
L["Vertical Nudge"] = "Cutucada Vertical" -- Needs review
L["Vertical Position"] = "Posição Vertical"
L["Visibility"] = "Visibilidade"
L["Width"] = "Largura"
-- L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."
L["Zone Text"] = "Texto da Zona" -- Needs review
L["Zoom In Button"] = "Botão aumentar o Zoom"
L["Zoom Out Button"] = "Botão diminuir o Zoom"

--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."

==> SexyMap-v9.2.15.zip: SexyMap/localization/ptBR.lua <==

if GetLocale() ~= "ptBR" then return end
local _, sm = ...
local L = sm.L
--L.dayNightButton = "Day/Night Indicator"
--L.classicLFGButton = "Classic LFG Button (When Available)"
--L.classicPVPButton = "Classic PvP Button (When Available)"
L["1. Background"] = "Fundo"
L["2. Border"] = "Borda"
L["3. Artwork"] = "Arte Visual" -- Needs review
L["4. Overlay"] = "Sobreposição" -- Needs review
L["5. Highlight"] = "Destaque" -- Needs review
L["Add Blend (additive)"] = "Adicionar Mistura (aditivo)" -- Needs review
L["Addon Buttons"] = "Botões de Addon"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Um perfil global já existe. Você será trocado para esse e sua interface (UI) será recarregada, você tem certeza disso?" -- Needs review
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Permitir que SexyMap assuma o direito de mover os botões no minimapa. Desligue isso se você tem outro mod que você pretende usar para posicionar seus botões do minimapa."
-- L["Alpha Key (1-bit alpha)"] = "Alpha Key (1-bit alpha)"
L["Always"] = "Sempre"
-- L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Are you sure you want to switch back to using a character specific profile? This will reload your UI."
L["Armored Man"] = "Homem Blindado" -- Needs review
L["A static amount to rotate the texture by."] = "Uma quantidade fixa para girar a textura por." -- Needs review
L["Auto Zoom-Out Delay"] = "Atraso do recuo do Zoom"
L["Backdrop Color"] = "Cor de fundo"
L["Backdrop Insets"] = "Inserções do Fundo" -- Needs review
L["Background Color"] = "Cor de fundo"
L["Background/edge"] = "Fundo/beira" -- Needs review
L["Background Texture"] = "Textura do Fundo"
L["Blend Mode"] = "Modo Misturar" -- Needs review
L["Blend (normal)"] = "Misturar (normal)" -- Needs review
L["Border Color"] = "Cor da Borda"
L["Border Edge Size"] = "Tamanho da beira da Borda"
L["Borders"] = "Bordas"
L["Border Texture"] = "Textura da Borda"
L["Boss Frames"] = "Quadros de Chefe"
L["Buttons"] = "Botões"
L["Calendar"] = "Calendário"
L["Challenge Mode Button (When Available)"] = "Botões do Modo Desafio (Quando disponível)"
L["Circle"] = "Círculo"
L["Clamp to screen"] = "Prender a tela" -- Needs review
L["Clear & start over"] = "Limpar e começar de novo"
L["Clear the current borders and start fresh"] = "Limpar as bordas existentes e começar de novo"
L["Clock"] = "Relógio"
L["Coordinates"] = "Coordenadas"
L["Copy a Profile"] = "Copiar um perfil"
L["Copying this profile will reload your UI, are you sure?"] = "Copiar esse perfil vai recarregar a interface (UI), você tem certeza disso?"
L["Create a new border"] = "Criar uma nova borda"
L["Current Borders"] = "Bordas atuais" -- Needs review
L["Default Presets"] = "Predefinições padrão" -- Needs review
L["Delete"] = "Deletar"
L["Delete a Profile"] = "Deletar um perfil"
L["Diamond"] = "Diamante"
L["Disable (opaque)"] = "Desabilitar (opacidade)"
L["Disable Rotation"] = "Desabilitar Rotação"
L["Drag Radius"] = "Área de arrasto" -- Needs review
L["Dungeon Difficulty Indicator (When Available)"] = "Indicador de Dificuldade de Masmorra (Quando disponível)"
L["Dynamic Buttons"] = "Botões dinâmicos"
L["Enable"] = "Habilitar"
-- L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Enable a backdrop and border for the minimap. This will let you set square borders more easily."
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Habilitar o HUD do minimapa. Isto é muito útil para coletar recursos, mas por motivos técnicos, o HUD do mapa e o minimapa normal não podem ser exibidos ao mesmo tempo. Ligando o HUD do mapa irá desligar o minimapa." -- Needs review
L["Enable Coordinates"] = "Habilitar Coordenadas"
L["Enable Hudmap"] = "Habilitar Hudmap"
L["Enable Minimap Fader"] = "Habilitar Ocultação do Minimapa" -- Needs review
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Coloque um nome para criar uma nova borda. O nome pode ser qualquer coisa que você ache que vai lhe ajudar a identificar a borda."
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Entre o caminho inteiro da textura que deseja usar. É recomendado que você use alguma Addon como |cffff6600TexBrowser|r para achar a textura que deseja usar."
-- L["Entry Options"] = "Entry Options"
-- L["Faded Circle (Large)"] = "Faded Circle (Large)"
-- L["Faded Circle (Small)"] = "Faded Circle (Small)"
-- L["Faded Square"] = "Faded Square"
-- L["Fader"] = "Fader"
L["Font"] = "Fonte"
L["Font Color"] = "Cor da Fonte"
L["Font Size"] = "Tamanho da fonte"
L["Force a square texture. Fixed distortion on square textures."] = "Forçar uma textura quadrada. Distorção fixa em texturas quadradas." -- Needs review
L["Garrison Button (When Available)"] = "Botão da Guarnição (Quando Disponível)" -- Needs review
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Indicador de dificuldade de Masmorra de Guilda (Quando disponível)"
L["Heart"] = "Coração" -- Needs review
L["Height"] = "Altura" -- Needs review
L["Hexagon"] = "Hexágono" -- Needs review
L["Hide default border"] = "Esconder borda padrão"
L["Hide the default border on the minimap."] = "Esconder a borda padrão no minimapa."
L["Horizontal Nudge"] = "Cutucada Horizontal" -- Needs review
L["Horizontal Position"] = "Posição Horizontal"
L["Hover Opacity"] = "Opacidade do mouse sobre o minimapa"
L["HUD Color"] = "Cor da HUD" -- Needs review
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "Se você aproximar o mapa, está função automaticamente afastará depois de um período de tempo (segundos). Usar o valor 0 desabilitará o afastamento automático." -- Needs review
L["Keybinding"] = "Tecla de atalho"
L["Layer"] = "Camada"
L["Let SexyMap control button visibility"] = "Deixar o SexyMap controlar a visibilidade dos botões"
L["Let SexyMap handle button dragging"] = "Deixar o SexyMap controlar o movimento dos botões"
L["Lock Button Dragging"] = "Bloquear o movimento de botões"
L["Lock Minimap"] = "Bloquear o minimapa"
L["Map Button"] = "Botão do mapa"
L["Minimap shape"] = "Formato do minimapa"
L["Mod Blend (modulative)"] = "Mistura do Mod (modular)" -- Needs review
L["Movers"] = "Movedores" -- Needs review
L["Name"] = "Nome"
L["Never"] = "Nunca"
L["New Mail Indicator (When Available)"] = "Indicador de nova carta (Quando disponível)"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "Não existe nenhum perfil global. Seu perfil em uso será copiado e usado como um perfil global, você tem certeza disso? Isto também irá recarregar sua interface (UI)." -- Needs review
L["Normal Opacity"] = "Opacidade normal"
L["Objectives Tracker"] = "Rastreador de Objetivos"
L["Octagon"] = "Octágono"
L["On Hover"] = "Mouse sobre o minimapa" -- Needs review
L["Opacity"] = "Opacidade"
L["Open TexBrowser"] = "Abrir TexBrowser"
L["Ping"] = "Silvo" -- Needs review
L["Preset"] = "Predefinido"
L["Prevent the minimap from being moved off the screen"] = "Previne que o minimapa seja movido fora dos limites de tela"
L["Profiles"] = "Perfis"
-- L["Queue Status (PvP/LFG) Button (When Available)"] = "Queue Status (PvP/LFG) Button (When Available)"
L["Quickly change the look of your minimap by using a minimap preset."] = "Mude rapidamente o visual de seu minimapa ao usar uma predefinição de minimapa."
L["Really delete this border?"] = "Deseja mesmo deletar essa borda?"
L["Really delete this preset? This can't be undone."] = "Deseja mesmo deletar essa predefinição? Este processo não poderá ser desfeito." -- Needs review
L["Really delete this profile?"] = "Deseja mesmo deletar este perfil?"
L["(Requires button visibility control in the Buttons menu)"] = "(Requer controle de visibilidade dos botôes no menu Botões)"
L["Reset Current Profile"] = "Resetar perfil atual" -- Needs review
L["Resetting this profile will reload your UI, are you sure?"] = "Resetar esse perfil irá recarregar sua interface (UI), você tem certeza disso?"
L["Right Click Configure"] = "Configuração ao clicar com o botão direito" -- Needs review
L["Right clicking the map will open the SexyMap options"] = "Clicar com o botão direito no mapa irá abrir as opções do SexyMap" -- Needs review
L["Rotation Speed (seconds)"] = "Velocidade da Rotação (segundos)" -- Needs review
L["Rounded - Bottom"] = "Arredondado - Canto Inferior" -- Needs review
L["Rounded - Bottom Left"] = "Arredondado - Canto Inferior Esquerdo" -- Needs review
L["Rounded - Bottom Right"] = "Arredondado - Canto Inferior Direito" -- Needs review
L["Rounded - Left"] = "Arredondado - Esquerdo" -- Needs review
L["Rounded - Right"] = "Arredondado - Direito" -- Needs review
L["Rounded - Top"] = "Arredondado - Canto Superior" -- Needs review
L["Rounded - Top Left"] = "Arredondado - Canto Superior Esquerdo" -- Needs review
L["Rounded - Top Right"] = "Arredondado - Canto Superior Direito" -- Needs review
L["Route 66"] = "Rota 66" -- Needs review
L["Save current settings as preset..."] = "Salvar definições em uso como predefinido..." -- Needs review
L["Scale"] = "Escala"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Selecione uma predefinição para carregar suas definições. Este processo irá apagar qualquer uma das suas bordas em uso." -- Needs review
L["Select preset to load"] = "Selecione predefinição para carregar" -- Needs review
L["SharedMedia Border"] = "Borda SharedMedia" -- Needs review
L["SharedMedia Texture"] = "Textura SharedMedia" -- Needs review
L["Show inside chat"] = "Mostrar dentro da janela de bate-papo" -- Needs review
L["Show North Tag"] = "Mostrar o indicador do Norte no minimapa"
L["Show on minimap"] = "Mostrar no minimapa"
L["Show %s:"] = "Mostrar %s:" -- Needs review
L["Show who pinged"] = "Mostrar quem deu o silvo" -- Needs review
L["Snowflake"] = "Floco de neve" -- Needs review
L["Spice up your minimap with some sexy options."] = "Dê uma apimentada no seu minimapa com algumas opções sexy."
L["Square"] = "Quadrado" -- Needs review
L["Standard Buttons"] = "Botões Padrões"
L["Static Rotation"] = "Rotação estática"
L["TexBrowser Not Installed"] = "TexBrowser não instalado"
L["Text Color"] = "Cor do texto"
L["Texture"] = "Textura"
L["Texture Options"] = "Opções de textura"
L["Texture Path"] = "Localização da textura"
L["Texture Tint"] = "Tintura da textura" -- Needs review
L["Text Width"] = "Largura do texto"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "O HudMap suporta vários addons. Se você tiver qualquer um dos addons abaixo instalado, eles será mostrado no HudMap." -- Needs review
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "O tempo que isso leva (em segundos) para completar uma rotação. Uma definição em 0 desliga a rotação." -- Needs review
L["This will wipe out any current settings!"] = "Isto irá apagar todas as outras configurações!"
L["Tile Background"] = "Fundo do azulejo" -- Needs review
L["Tile Size"] = "Tamanho do azulejo" -- Needs review
L["Toggle HudMap On/Off"] = "Ligar/Desligar HudMap"
L["Tracking Button"] = "Botão de Rastreamento"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Desligue isso se você quer que outro mod seja utilizado para controlar quais botões são visiveis no minimapa."
L["Use Global Profile"] = "Usar Perfil Global"
L["User-Submitted Presets"] = "Predefinições feitas por usuários"
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Use o perfil global se você quer o mesmo visual para todos os personagens, ou use um perfil específico-para-um-personagem para um visual único para cada personagem."
L["Vehicle Seat"] = "Assento do Veículo"
L["Vertical Nudge"] = "Cutucada Vertical" -- Needs review
L["Vertical Position"] = "Posição Vertical"
L["Visibility"] = "Visibilidade"
L["Width"] = "Largura"
-- L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."
L["Zone Text"] = "Texto da Zona" -- Needs review
L["Zoom In Button"] = "Botão aumentar o Zoom"
L["Zoom Out Button"] = "Botão diminuir o Zoom"

-- Coordinates.lua
--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."
--L.Precision = "Precision"

-- Movers.lua
--L.moversDescription = "Enable the ability to move specific UI elements."
--L.disableWarning = "Disabling this will temporarily show the loading screen. Are you sure?"
--L.enableObject = "Enable %s"
--L.lockObject = "Lock %s"
--L.pvpCaptureBar = "PvP Capture Bar"
--L.buffs = "Buffs/Debuffs"
--L.topCenterObjectivesWidget = "Top-Screen Objective/PvP Tracker"
